#
# spec file for package perl-Sys-Virt
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           perl-Sys-Virt
Version:        11.0.0
Release:        1.1
%define cpan_name Sys-Virt
Summary:        Represent and manage a libvirt hypervisor connection
License:        ClArtistic OR GPL-2.0-or-later
Group:          Development/Libraries/Perl
URL:            https://metacpan.org/release/Sys-Virt
Source:         %{cpan_name}-%{version}.tar.gz
# Build
BuildRequires:  libvirt-devel >= %{version}
BuildRequires:  perl(ExtUtils::CBuilder)
BuildRequires:  perl(Module::Build)
# Runtime
BuildRequires:  perl(XSLoader)
BuildRequires:  perl(overload)
BuildRequires:  perl(strict)
BuildRequires:  perl(warnings)
# Tests only
BuildRequires:  perl(Sys::Hostname)
BuildRequires:  perl(Test::More)
BuildRequires:  perl(Time::HiRes)
BuildRequires:  perl(XML::XPath)
BuildRequires:  perl(XML::XPath::XMLParser)
BuildRequires:  perl(base)
# Optional tests only
BuildRequires:  perl(Test::Pod) >= 1.00
BuildRequires:  perl(Test::Pod::Coverage) >= 1.00
%if 0%{?suse_version} >= 1500
BuildRequires:  perl(Test::CPAN::Changes)
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{perl_requires}

%description
The Sys::Virt module provides a Perl XS binding to the libvirt virtual
machine management APIs. This allows machines running within arbitrary
virtualization containers to be managed with a consistent API.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
%{__perl} Build.PL installdirs=vendor
./Build

%check
./Build test

%install
./Build install destdir=%{buildroot} create_packlist=0
%perl_process_packlist
%perl_gen_filelist

%clean
%{__rm} -rf %{buildroot}

%files -f %{name}.files
%defattr(644,root,root,755)
%license LICENSE
%doc AUTHORS Changes HACKING perl-Sys-Virt.spec README

%changelog
* Fri Feb 14 2025 James Fehlig <jfehlig@suse.com>
- Update to 11.0.0
  - Add all new APIs and constants in libvirt 11.0.0
  - jsc#PED-5899, jsc#PED-8909, jsc#PED-9543, jsc#PED-9854,
    jsc#PED-9855
* Fri Nov  1 2024 James Fehlig <jfehlig@suse.com>
- Update to 10.9.0
  - Add all new APIs and constants in libvirt 10.9.0
  - jsc#PED-8909, jsc#PED-9854, jsc#PED-9855
* Tue Oct  1 2024 James Fehlig <jfehlig@suse.com>
- Update to 10.6.0
  - Add all new APIs and constants in libvirt 10.6.0
  - jsc#PED-8909
* Tue Jul 16 2024 James Fehlig <jfehlig@suse.com>
- Update to 10.5.0
  - Add all new APIs and constants in libvirt 10.5.0
* Thu May  2 2024 James Fehlig <jfehlig@suse.com>
- Update to 10.2.0
  - Add all new APIs and constants in libvirt 10.2.0
* Tue Mar  5 2024 James Fehlig <jfehlig@suse.com>
- Update to 10.1.0
  - Add all new APIs and constants in libvirt 10.1.0
* Wed Jan 17 2024 James Fehlig <jfehlig@suse.com>
- Update to 10.0.0
  - Add all new APIs and constants in libvirt 10.0.0
  - jsc#PED-3226, jsc#PED-3279, jsc#PED-4931, jsc#PED-5432,
    jsc#PED-6851
* Mon Nov 27 2023 James Fehlig <jfehlig@suse.com>
- Update to 9.8.0
  - Add all new APIs and constants in libvirt 9.8.0
  - jsc#PED-3226, jsc#PED-3279, jsc#PED-4931, jsc#PED-5432,
    jsc#PED-6851
* Fri Sep  8 2023 James Fehlig <jfehlig@suse.com>
- Update to 9.7.0
  - Add all new APIs and constants in libvirt 9.7.0
  - jsc#PED-3279
* Thu Jul  6 2023 James Fehlig <jfehlig@suse.com>
- Drop downstream-only suse-set-migration-constraints.patch
* Fri Jun  2 2023 James Fehlig <jfehlig@suse.com>
- Update to 9.4.0
  - Add all new APIs and constants in libvirt 9.4.0
* Tue May  2 2023 James Fehlig <jfehlig@suse.com>
- Update to 9.2.0
  - Add all new APIs and constants in libvirt 9.2.0
* Tue Jan 17 2023 James Fehlig <jfehlig@suse.com>
- Update to 9.0.0
  - Add all new APIs and constants in libvirt 9.0.0
  - jsc#PED-620
* Thu Dec  8 2022 James Fehlig <jfehlig@suse.com>
- Update to 8.10.0
  - Add all new APIs and constants in libvirt 8.10.0
  - jsc#PED-1472
* Fri Nov 11 2022 James Fehlig <jfehlig@suse.com>
- Update to 8.9.0
  - Add all new APIs and constants in libvirt 8.9.0
  - jsc#PED-620, jsc#PED-1540
* Wed Oct  5 2022 James Fehlig <jfehlig@suse.com>
- Update to 8.8.0
  - Add all new APIs and constants in libvirt 8.8.0
  - jsc#PED-620, jsc#PED-1540
* Tue Jul  5 2022 James Fehlig <jfehlig@suse.com>
- Update to 8.5.0
  - Add all new APIs and constants in libvirt 8.5.0
* Mon May  9 2022 James Fehlig <jfehlig@suse.com>
- Update to 8.3.0
  - Add all new APIs and constants in libvirt 8.3.0
* Thu Mar  3 2022 James Fehlig <jfehlig@suse.com>
- Update to 8.1.0
  - Add all new APIs and constants in libvirt 8.1.0
* Tue Jan 18 2022 James Fehlig <jfehlig@suse.com>
- Update to 8.0.0
  - Add all new APIs and constants in libvirt 8.0.0
  - jsc#SLE-11435, jsc#SLE-18354
* Thu Dec  2 2021 James Fehlig <jfehlig@suse.com>
- Update to 7.10.0
  - Add all new APIs and constants in libvirt 7.10.0
  - jsc#SLE-18260, jsc#SLE-19264
* Thu Nov  4 2021 James Fehlig <jfehlig@suse.com>
- Update to 7.9.0
  - Add all new APIs and constants in libvirt 7.9.0
  - jsc#SLE-19264
* Fri Oct  1 2021 James Fehlig <jfehlig@suse.com>
- Update to 7.8.0
  - Add all new APIs and constants in libvirt 7.8.0
  - jsc#SLE-18260
* Fri Sep  3 2021 James Fehlig <jfehlig@suse.com>
- Update to 7.7.0
  - Add all new APIs and constants in libvirt 7.7.0
  - jsc#SLE-18446
* Tue Jul  6 2021 James Fehlig <jfehlig@suse.com>
- Update to 7.5.0
  - Add all new APIs and constants in libvirt 7.5.0
* Mon May 17 2021 James Fehlig <jfehlig@suse.com>
- Update to 7.3.0
  - Add all new APIs and constants in libvirt 7.3.0
* Thu Apr  1 2021 James Fehlig <jfehlig@suse.com>
- Update to 7.2.0
  - Add all new APIs and constants in libvirt 7.2.0
* Tue Mar  2 2021 James Fehlig <jfehlig@suse.com>
- Update to 7.1.0
  - Add all new APIs and constants in libvirt 7.1.0
* Tue Jan 19 2021 James Fehlig <jfehlig@suse.com>
- Update to 7.0.0
  - Add all new APIs and constants in libvirt 7.0.0
  - jsc#SLE-15860
* Tue Jan  5 2021 James Fehlig <jfehlig@suse.com>
- Update suse-set-migration-constraints.patch
  Remove code which handled --max_factor. The total amount of
  transferred data is no indicator to trigger the final stop+copy.
  This should have been removed during upgrade to Xen 4.7.
  Reduce default value of --max_iters from 5 to 2.
  The workload within domU will continue to produce dirty pages.
  It is unreasonable to expect any slowdown during migration.
  Now there is one initial copy of all memory, one instead of four
  iteration for dirty memory, and a final copy iteration prior move.
* Wed Dec  2 2020 James Fehlig <jfehlig@suse.com>
- Update to 6.10.0
  - Add all new APIs and constants in libvirt 6.10.0
  - jsc#SLE-13688
* Mon Nov  2 2020 James Fehlig <jfehlig@suse.com>
- Update to 6.8.0
  - Add all new APIs and constants in libvirt 6.8.0
  - jsc#SLE-13688, jsc#SLE-16754
- Add new file _service for tar_scm source service
* Wed May  6 2020 James Fehlig <jfehlig@suse.com>
- Update to 6.3.0
  - Add all new APIs and constants in libvirt 6.3.0
* Wed Mar 18 2020 James Fehlig <jfehlig@suse.com>
- Update to 6.1.0
  - Add all new APIs and constants in libvirt 6.1.0
* Thu Feb  6 2020 James Fehlig <jfehlig@suse.com>
- Update to 6.0.0
  - Add all new APIs and constants in libvirt 6.0.0
* Thu Oct 10 2019 James Fehlig <jfehlig@suse.com>
- Update to 5.8.0
  - Add all new APIs and constants in libvirt 5.8.0
* Thu Sep  5 2019 James Fehlig <jfehlig@suse.com>
- Update to 5.7.0
  - Add all new APIs and constants in libvirt 5.7.0
* Mon Aug 12 2019 James Fehlig <jfehlig@suse.com>
- Update to 5.6.0
  - Add all new APIs and constants in libvirt 5.6.0
* Wed Jul 24 2019 James Fehlig <jfehlig@suse.com>
- Update to 5.5.0
  - Add all new APIs and constants in libvirt 5.5.0
* Wed Apr  3 2019 James Fehlig <jfehlig@suse.com>
- Update to 5.2.0
  - Add all new APIs and constants in libvirt 5.2.0
* Wed Mar  6 2019 James Fehlig <jfehlig@suse.com>
- Update to 5.1.0
  - Add all new APIs and constants in libvirt 5.1.0
  - jsc#SLE-3887, jsc#SLE-4480, jsc#SLE-4577
* Tue Jan 22 2019 James Fehlig <jfehlig@suse.com>
- Update to 5.0.0
  - Add all new APIs and constants in libvirt 5.0.0
  - FATE#320928, FATE#325817, FATE#326380, FATE#326698
* Tue Dec  4 2018 James Fehlig <jfehlig@suse.com>
- Update to 4.10.0
  - Add all new APIs and constants in libvirt 4.10.0
  - FATE#320928, FATE#325817, FATE#326380, FATE#326698
* Fri Oct  5 2018 James Fehlig <jfehlig@suse.com>
- Use %%license for LICENSE file
* Fri Oct  5 2018 James Fehlig <jfehlig@suse.com>
- Update to 4.8.0
  - Add all new APIs and constants in libvirt 4.8.0
* Thu Sep 20 2018 James Fehlig <jfehlig@suse.com>
- Update to 4.7.0
  - Add all new APIs and constants in libvirt 4.7.0
* Mon Aug 13 2018 jfehlig@suse.com
- Update to 4.6.0
  - Add all new APIs and constants in libvirt 4.6.0
* Fri Jul 27 2018 jfehlig@suse.com
- Update to 4.5.0
  - Add all new APIs and constants in libvirt 4.5.0
* Thu Jun  7 2018 jfehlig@suse.com
- Update to 4.4.0
  - Add all new APIs and constants in libvirt 4.4.0
- spec: Modernize list of build deps to match required packages
- build: Switch to using Module::Build
* Thu Apr  5 2018 jfehlig@suse.com
- Update to 4.2.0
  - Add all new APIs and constants in libvirt 4.2.0
* Mon Mar  5 2018 jfehlig@suse.com
- Update to 4.1.0
  - Add all new APIs and constants in libvirt 4.1.0
  - Dropped patches: c069787e-virstream-fix.patch
* Mon Dec 18 2017 jfehlig@suse.com
- Fix check of return value from virStreamRecv*
  c069787e-virstream-fix.patch
  bsc#1073177
* Fri Dec 15 2017 jfehlig@suse.com
- Update to 3.9.1
  - Fix package location of lifecycle constants
* Mon Nov  6 2017 jfehlig@suse.com
- Update to 3.9.0
  - Add all new APIs and constants in libvirt 3.9.0
* Thu Oct  5 2017 jfehlig@suse.com
- Update to 3.8.0
  - Add all new APIs and constants in libvirt 3.8.0
* Fri Sep 15 2017 jfehlig@suse.com
- Update to 3.7.0
  - Add all new APIs and constants in libvirt 3.7.0
* Thu Jul  6 2017 jfehlig@suse.com
- Update to 3.5.0
  - Add all new APIs and constants in libvirt 3.5.0
* Mon Jun  5 2017 jfehlig@suse.com
- Update to 3.4.0
  - Add all new APIs and constants in libvirt 3.4.0
* Mon May  8 2017 jfehlig@suse.com
- Update to 3.3.0
  - Add all new APIs and constants in libvirt 3.3.0
  - FATE#319684, FATE#321335, FATE#321349
* Mon Apr  3 2017 jfehlig@suse.com
- Update to 3.2.0
  - Add all new APIs and constants in libvirt 3.2.0
  - FATE#319684, FATE#321335, FATE#321349
* Mon Mar  6 2017 jfehlig@suse.com
- Update to 3.1.0
  - Add all new APIs and constants in libvirt 3.1.0
* Thu Feb  2 2017 jfehlig@suse.com
- SLE12 SP2 FATEs merged via version updates of the Factory
  perl-Sys-Virt package:
  FATE#316228, FATE#316628, FATE#319531, FATE#319810, FATE#320490
- SLE12 SP1 FATEs merged via version updates of the Factory
  perl-Sys-Virt package:
  FATE#314466, FATE#314497, FATE#315157, FATE#318383
* Thu Jan 19 2017 jfehlig@suse.com
- Update to 3.0.0
  - Add all new APIs and constants in libvirt 3.0.0
* Tue Dec  6 2016 jfehlig@suse.com
- Update to 2.5.0
  - Add all new APIs and constants in libvirt 2.5.0
* Wed Nov  2 2016 jfehlig@suse.com
- Update to 2.4.0
  - Add all new APIs and constants in libvirt 2.4.0
* Wed Oct 12 2016 jfehlig@suse.com
- Update to 2.3.0
  - Add all new APIs and constants in libvirt 2.3.0
* Sat Aug 20 2016 jfehlig@suse.com
- Update to 2.1.0
  - Add all new APIs and constants in libvirt 2.1.0
* Fri Jul  1 2016 jfehlig@suse.com
- Update to 2.0.0
  - Add all new APIs and constants in libvirt 2.0.0
* Fri Jun 24 2016 jfehlig@suse.com
- Add migration constraint parameters
  suse-set-migration-constraints.patch
  FATE#316614, bsc#859868
* Tue Jun  7 2016 jfehlig@suse.com
- Update to 1.3.5
  - Add all new APIs and constants in libvirt 1.3.5
* Wed May  4 2016 jfehlig@suse.com
- Update to 1.3.4
  - Add all new APIs and constants in libvirt 1.3.4
* Tue Apr 12 2016 jfehlig@suse.com
- Update to 1.3.3
  - Add all new APIs and constants in libvirt 1.3.3
* Tue Mar  1 2016 jfehlig@suse.com
- Update to 1.3.2
  - Add all new APIs and constants in libvirt 1.3.2
* Thu Jan 28 2016 jfehlig@suse.com
- Update to 1.3.1
  - Add all new APIs and constants in libvirt 1.3.1
* Mon Dec 21 2015 jfehlig@suse.com
- Update to 1.3.0
  - Add all new APIs and constants in libvirt 1.3.0
* Tue Dec  1 2015 jfehlig@suse.com
- Update to 1.2.21
  - Add all new APIs and constants in libvirt 1.2.21
* Sat Sep  5 2015 jfehlig@suse.com
- Update to 1.2.19
  - Add all new APIs and constants in libvirt 1.2.19
* Tue Aug  4 2015 jfehlig@suse.com
- Update to 1.2.18
  - Add all new APIs and constants in libvirt 1.2.18
* Fri Jul 17 2015 jfehlig@suse.com
- Update to 1.2.17
  - Add all new APIs and constants in libvirt 1.2.17
* Mon Jun  1 2015 jfehlig@suse.com
- Update to 1.2.16
  - Add all new APIs and constants in libvirt 1.2.16
* Thu May 21 2015 jfehlig@suse.com
- Update to 1.2.15
  - Add all new APIs and constants in libvirt 1.2.15
* Mon Apr 13 2015 jfehlig@suse.com
- Update to 1.2.14
  - Add all new APIs and constants in libvirt 1.2.14
* Fri Mar  6 2015 jfehlig@suse.com
- Update to 1.2.13
  - Add all new APIs and constants in libvirt 1.2.13
* Tue Jan 27 2015 jfehlig@suse.com
- Update to 1.2.12
  - Add all new APIs and constants in libvirt 1.2.12
* Mon Dec 15 2014 jfehlig@suse.com
- Update to 1.2.11
  - Add all new APIs and constants in libvirt 1.2.11
* Thu Oct  2 2014 jfehlig@suse.com
- Update to 1.2.9
  - Add all new APIs and constants in libvirt 1.2.9
* Wed Sep 10 2014 jfehlig@suse.com
- Update to 1.2.8
  - Add all new APIs and constants in libvirt 1.2.8
* Wed Jul  2 2014 jfehlig@suse.com
- Update to 1.2.6
  - Add all new APIs and constants in libvirt 1.2.6
* Mon Jun  2 2014 jfehlig@suse.com
- Update to 1.2.5
  - Add all new APIs and constants in libvirt 1.2.5
* Tue May  6 2014 jfehlig@suse.com
- Update to 1.2.4
  - Add all new APIs and constants in libvirt 1.2.4
* Mon Apr  7 2014 jfehlig@suse.com
- Update to 1.2.3
  - Add all new APIs and constants in libvirt 1.2.3
* Mon Mar  3 2014 jfehlig@suse.com
- Update to 1.2.2
  - Add all new APIs and constants in libvirt 1.2.2
* Wed Jan 22 2014 jfehlig@suse.com
- Update to 1.2.1
  - Add new network event APIs from libvirt 1.2.1
  - Add new constants in libvirt 1.2.1
  - Drop upstreamed Sys-Virt-1.2.0.patch
* Sat Dec 14 2013 ohering@suse.de
- Use correct free() in get_cpu_model_names
  Sys-Virt-1.2.0.patch
* Fri Dec  6 2013 jfehlig@suse.com
- Update to 1.2.0
  - Add all new APIs and constants in libvirt 1.2.0
* Wed Nov 20 2013 jfehlig@suse.com
- Update to 1.1.4
  - Add all new APIs and constants in libvirt 1.1.4
* Fri Oct  4 2013 jfehlig@suse.com
- Update to 1.1.2
  - Add all new APIs and constants in libvirt 1.1.2
* Tue Jul 30 2013 jfehlig@suse.com
- Update to 1.1.1
  - Add all new APIs and constants in libvirt 1.1.1
* Tue Jul 30 2013 jfehlig@suse.com
- Update to 1.1.0
  - Add support for v3 of migration APIs
  - Add all new constants in libvirt 1.1.0
  - Fix handling of sparse typed parameters
  - Fix misc typos in docs
* Fri May 17 2013 jfehlig@suse.com
- Update to 1.0.5
  - Add all new APIs and constants in libvirt 1.0.5
* Wed Mar  6 2013 jfehlig@suse.com
- Update to 1.0.3
  - Add all new APIs and constants in libvirt 1.0.3
* Wed Feb 27 2013 jfehlig@suse.com
- Update to 1.0.2
  - Add all new APIs and constants in libvirt 1.0.2
* Tue Feb 26 2013 jfehlig@suse.com
- Update to 1.0.1
  - Add all new APIs and constants in libvirt 1.0.1
  - Fix typo preventing listing of NWFilters
  - Add more testing of object list APIs
  - Fix some incorrect error handling tests in binding
  - Remove bogus compare < 0 for size_t variables
  - Fix const-ness of functions for populating constants
  - Add option to turn on more GCC warning flags
  - Fix typos in POD docs
* Sun Feb 24 2013 ohering@suse.de
- BuildRequire: perl-macros only in sles11 builds to fix build in 11.4
* Wed Nov 28 2012 cfarrell@suse.com
- license update: GPL-2.0+ or ClArtistic
* Mon Nov 26 2012 jfehlig@suse.com
- Update to 1.0.0 [fate#312159]
  - Add all new APIs in libvirt 1.0.0
* Wed Nov 14 2012 ohering@suse.de
- Update license to be GPL-2.0+
* Fri Oct 12 2012 jfehlig@suse.com
- Update to 0.10.2 [fate#312159]
  - Add all new APIs in libvirt 0.10.2
* Wed Sep 12 2012 jfehlig@suse.com
- Update to 0.9.13
  - Add all new APIs in libvirt 0.9.13
* Thu May 31 2012 jfehlig@suse.com
- Update to 0.9.11
  - Add all new APIs in libvirt 0.9.11
  - Add test case to validate API coverage
  - Fix misc POD docs bugs
  - Fix reference handling in block stats
  - Add handling of VIR_TYPED_PARAM_STRING
* Wed Feb 15 2012 jfehlig@suse.com
- Update to 0.9.10
  - Add all new APIs in libvirt 0.9.10
  - Add some constants missing from previous releases
  - Clarify docs for shutdown/destroy APIs
* Wed Feb  8 2012 idonmez@suse.com
- Fix license to be GPL-1.0+
* Fri Jan  6 2012 jfehlig@suse.com
- Update to 0.9.8
  - Add all new APIs in libvirt 0.9.8
  - Requires libvirt >= 0.9.8
* Thu Sep 29 2011 jfehlig@suse.com
- Update to 0.9.5
  - Add all new APIs in libvirt 0.9.5
  - Requires libvirt >= 0.9.5
* Thu Aug  4 2011 jfehlig@suse.com
- Update to 0.9.4
  - Add all new APIs in libvirt 0.9.4
  - Requires libvirt >= 0.9.4
  - Add missing VIR_DUMP_* and VIR_MIGRATE_* constants
  from previous releases
* Wed Jul 13 2011 jfehlig@suse.de
- Update to 0.9.2
  - Changed version numbering to track the corresponding minimum
  required libvirt releases
  - Add all new APIs in libvirt 0.9.2
  - Requires libvirt >= 0.9.2
* Fri Jul  1 2011 jfehlig@suse.de
- Update to 0.2.7
  - Honour flags parameter when dumping XML
  - Use thread local error APIs exclusively
  - Fix bogus extra URI parameter in migrate_to_uri function
  - Implement all virStream APIs in Sys::Virt::Stream
  - Impement virDomainGetSysinfo binding
  - Call virInitialize when loading module
  - Add all missing error constants
  - Requires libvirt >= 0.8.8
* Tue Jun 28 2011 jfehlig@suse.de
- Initial packaging of libvirt perl bindings for SUSE
